define( function ( require ) {
    "use strict";

    var funcProc = require( 'funcproc' ),
        Backbone = require( 'backbone' ),
        Bootstrap = require( 'bootstrap' );

    var devicemodel = '',
        deviceplatform = '',
        deviceversion = '',
        deviceLatitude = '',
        deviceLongitude = '';

    return Backbone.Router.extend( {

        routes: {
            '': 'home',
            'home': 'home',
            'agency-status': 'agencyStatus',
            'agsearch/:agname/:searchopt': 'agencySearch',
            'joborders': 'jobOrders',
            'josearch/:pos/:searchopt': 'joSearch',
            'agency-jobs/:agname': 'agencyJobs',
            'air': 'airMenuView',
            'wiir': 'wiir',
            'iair': 'iair',
            'htair': 'htair',
            'mooir': 'mooir',
            'poic': 'poic',
            'tips': 'tips',
            'topten': 'topTen',
            'oes': 'oes',
            'kautusan': 'kautusan',
            'about': 'waAbout',
            'contact-us': 'contactus',
            'region': 'region'
        },

        initialize: function () {

            this.bindEvents();
            this.doDefaultHeader();
            this.doHomeFooter();
            $(document).on('focus','input[type="text"], input[type="email"], input[type="search"]', function(){
                $('#to-hide-footer').hide();
            });
            $(document).on('blur','input[type="text"], input[type="email"], input[type="search"]', function(){
                $('#to-hide-footer').show();
            });
            require( [ 'views/home/HomeView' ], function ( HomeView ) {
                var homeView = new HomeView();
                homeView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 400 );
            } )
            FastClick.attach( document.body );
        },
        bindEvents: function () {
            document.addEventListener( 'deviceready', this.onDeviceReady, false );
        },

        onDeviceReady: function () {
            if ( navigator.notification ) { // Override default HTML alert with native dialog

                window.alert = function ( message, title, buttonName, callback ) {
                    navigator.notification.alert(
                        message, // message
                        callback, // callback
                        title, // title
                        buttonName // buttonName
                    );
                };

            }

            devicemodel = encodeURIComponent( device.model );
            deviceplatform = encodeURIComponent( device.platform );
            deviceversion = encodeURIComponent( device.version );

            navigator.geolocation.getCurrentPosition(
                function ( position ) {
                    deviceLatitude = encodeURIComponent( position.coords.latitude );
                    deviceLongitude = encodeURIComponent( position.coords.longitude );
                }, function ( error ) {
                    deviceLatitude = encodeURIComponent( 0.0 );
                    deviceLongitude = encodeURIComponent( 0.0 );
                } );

            FastClick.attach( document.body );
        },

        hideHomeButton: function () {
            $( ".hb" )
                .hide();
        },
        showHomeButton: function () {
            $( ".hb" )
                .show();

        },
        home: function () {

            $( 'body' )
                .css( 'background-color', '#FFFFFF' );
            $( '#header' )
                .css( 'background-color', '#0066CC' );
            this.doDefaultHeader();
            this.doHomeFooter();
            this.hideHomeButton();
            require( [ 'views/home/HomeView' ], function ( HomeView ) {
                var homeView = new HomeView();
                homeView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 400 );
            } )


        },
        doDefaultHeader: function () {
            /* description: initialize footer;
                target-dom #footer-container;
                */
            require( [ 'views/common/DefaultHeaderView' ], function ( DefaultHeaderView ) {
                var defaultHeaderView = new DefaultHeaderView;
                defaultHeaderView.render();
            } )
        },
        doDefaultFooter: function () {
            /* description: initialize footer;
                target-dom #footer-container;
                */
            $( '#footer-container' )
                .show();
            require( [ 'views/common/DefaultFooterView' ], function ( DefaultFooterView ) {
                var defaultFooterViewInstance = new DefaultFooterView;
                defaultFooterViewInstance.render();
            } )

        },
        doDefaultHeaderFooter: function () {
            $( 'body' )
                .css( 'background-color', '#FFFFFF' );
            $( '#header' )
                .css( 'background-color', '#0066CC' );

            this.doDefaultHeader();
            this.doDefaultFooter();

        },
        doHomeFooter: function () {
            /* description: initialize footer;
                target-dom #footer-container;
                */
            require( [ 'views/home/HomeFooterView' ], function ( HomeFooterView ) {
                var homeFooterViewInstance = new HomeFooterView;
                homeFooterViewInstance.render();
            } );
        },

        doAboutFooter: function () {
            /* description: initialize footer;
                target-dom #footer-container;
                */
            $( '#footer-container' )
                .hide();
            //require( [ 'views/common/AboutFooterView' ], function ( AboutFooterView ) {
            //    var aboutFooterView = new AboutFooterView;
            //    aboutFooterView.render();
            // } );
        },

        doAboutHeader: function () {
            /* description: initialize footer;
                target-dom #footer-container;
                */
            require( [ 'views/common/AboutHeaderView' ], function ( AboutHeaderView ) {
                var aboutHeaderView = new AboutHeaderView;
                aboutHeaderView.render();
            } )
        },
        doAboutHeaderFooter: function () {
            $( 'body' )
                .css( 'background-color', '#FFC019' );
            $( '#header' )
                .css( {
                    'background-color': '#FFC019',
                    'border-bottom': '0px'
                } );

            $( 'body' )
                .hide();
            this.doAboutHeader();
            this.doAboutFooter();

            $( 'body' )
                .fadeIn( 'normal', function () {

                } );;
        },
        agencyStatus: function () {
            /*
            description: Show Air Menu;
            target-dom #content;
            */
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            funcProc.removeBackButton();
            require( [ 'views/agencies/AgencyStatusView' ], function ( AgencyStatusView ) {
                var agencyStatusViewInstance = new AgencyStatusView();
                agencyStatusViewInstance.render();
            } );

        },
        agencySearch: function ( agname, searchopt ) {
            this.doDefaultHeaderFooter();
            funcProc.toast( "Searching Agency..." );
            require( [
                    'models/agencies/AgencySearchModel',
                    'views/agencies/AgencySearchView',
                ], function ( AgencySearchModel, AgencySearchView ) {

                var agencySearchModel = new AgencySearchModel();

                agencySearchModel.fetch( {
                    data: {
                        agname: encodeURIComponent( agname ),
                        searchopt: searchopt,
                        devicemodel: devicemodel,
                        deviceplatform: deviceplatform,
                        deviceversion: deviceversion,
                        deviceLatitude: deviceLatitude,
                        deviceLongitude: deviceLongitude

                    },
                    success: function ( data ) {
                        funcProc.toastHide();
                        var agencySearchView = new AgencySearchView( {
                            model: data,
                            agname: agname,
                            searchopt: searchopt
                        } );
                        agencySearchView.render();
                        $( "html, body" )
                            .animate( {
                                scrollTop: 0
                            }, 400 );
                    },
                    error: function ( model, error ) {
                        funcProc.toast( error );
                    }
                } );
            } );
        },
        jobOrders: function () {
            /*
            description: Show Joborder Form;
            target-dom #content;
            */
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            funcProc.removeBackButton();
            require( [ 'views/joborders/JoborderFormView' ], function ( JoborderFormView ) {
                var joborderFormViewInstance = new JoborderFormView();
                joborderFormViewInstance.render();
            } );
        },
        joSearch: function ( pos, searchopt ) {
            this.doDefaultHeaderFooter();
            funcProc.toast( 'Searching joborders..' );
            require( [
                    'views/joborders/JoborderSearchView',
                    'models/joborders/JoborderSearchModel'
                ], function ( JoborderSearchView, JoborderSearchModel ) {
                var joborderSearchModel = new JoborderSearchModel();
                joborderSearchModel.fetch( {
                    data: {
                        pos: encodeURIComponent( pos ),
                        searchopt: searchopt,
                        devicemodel: devicemodel,
                        deviceplatform: deviceplatform,
                        deviceversion: deviceversion,
                        deviceLatitude: deviceLatitude,
                        deviceLongitude: deviceLongitude
                    },
                    success: function ( data ) {
                        funcProc.toastHide();
                        var joborderSearchView = new JoborderSearchView( {
                            model: data,
                            pos: pos,
                            searchopt: searchopt
                        } );

                        joborderSearchView.render();
                        $( "html, body" )
                            .animate( {
                                scrollTop: 0
                            }, 400 );
                    },
                    error: function ( model, err ) {
                        funcProc.toast( err );
                    }

                } )
            } )
        },
        agencyJobs: function ( agname ) {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            funcProc.toast( 'Searching agency joborders...' );
            require( [
                    'views/agencies/AgencyJoborderView',
                    'models/agencies/AgencyJoborderModel'
                ], function ( AgencyJoborderView, AgencyJoborderModel ) {
                var agencyJoborderModel = new AgencyJoborderModel();

                agencyJoborderModel.fetch( {
                    data: {
                        agname: agname
                    },
                    success: function ( data ) {
                        funcProc.toastHide();
                        var agencyJoborderView = new AgencyJoborderView( {
                            model: data,
                            agname: agname
                        } );

                        agencyJoborderView.render();
                        $( "html, body" )
                            .animate( {
                                scrollTop: 0
                            }, 400 );
                    },
                    error: function ( model, err ) {
                        funcProc.toast( err );
                    }
                } );
            } )
        },
        airMenuView: function () {

            /*
            description: Show Air Menu;
            target-dom #content;
            */
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            funcProc.removeBackButton();
            require( [ 'views/air/AirMenuView' ], function ( AirMenuView ) {
                var airMenuViewInstance = new AirMenuView();
                airMenuViewInstance.render();
            } );
        },
        wiir: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/WiirView' ], function ( WiirView ) {
                var wiirView = new WiirView();
                wiirView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )
        },
        iair: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/IairView' ], function ( IairView ) {
                var iairView = new IairView();
                iairView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )

        },
        htair: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/HtairView' ], function ( HtairView ) {
                var htairView = new HtairView();
                htairView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )

        },
        mooir: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/MooirView' ], function ( MooirView ) {
                var mooirView = new MooirView();
                mooirView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )
        },
        poic: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/PoicView' ], function ( PoicView ) {
                var poicView = new PoicView();
                poicView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )

        },
        tips: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/TipsView' ], function ( TipsView ) {
                var tipsView = new TipsView();
                tipsView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )

        },
        topTen: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/TopTenView' ], function ( TopTenView ) {
                var topTenView = new TopTenView();
                topTenView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )

        },
        oes: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/OesView' ], function ( OesView ) {
                var oesView = new OesView();
                oesView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )
        },
        kautusan: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/air/KautusanView' ], function ( KautusanView ) {
                var kautusanView = new KautusanView();
                kautusanView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )

        },
        waAbout: function () {

            this.doAboutHeaderFooter();
            this.showHomeButton();
            require( [ 'views/workabroad/About' ], function ( About ) {
                var about = new About();
                about.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )
        },
        contactus: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/contactus/ContactusView' ], function ( ContactusView ) {
                var contactusView = new ContactusView();
                contactusView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )
        },
        region: function () {
            this.doDefaultHeaderFooter();
            this.showHomeButton();
            require( [ 'views/contactus/SateliteView' ], function ( SateliteView ) {
                var sateliteView = new SateliteView();
                sateliteView.render();
                $( "html, body" )
                    .animate( {
                        scrollTop: 0
                    }, 'fast' );
            } )

        }

    } )
} );